aboutsummaryrefslogtreecommitdiff
path: root/modules/sd_models_types.py
diff options
context:
space:
mode:
Diffstat (limited to 'modules/sd_models_types.py')
-rw-r--r--modules/sd_models_types.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/modules/sd_models_types.py b/modules/sd_models_types.py
index 5ffd2f4f..f911fbb6 100644
--- a/modules/sd_models_types.py
+++ b/modules/sd_models_types.py
@@ -22,7 +22,10 @@ class WebuiSdModel(LatentDiffusion):
"""structure with additional information about the file with model's weights"""
is_sdxl: bool
- """True if the model's architecture is SDXL"""
+ """True if the model's architecture is SDXL or SSD"""
+
+ is_ssd: bool
+ """True if the model is SSD"""
is_sd2: bool
"""True if the model's architecture is SD 2.x"""